"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var get_root_1 = require("../utils/get-root");
var build_selection_set_1 = require("./build-selection-set");
var transform_variables_1 = require("./transform-variables");
var debugging_1 = require("../debugging");
var printer_1 = require("graphql/language/printer");
function transformOperation(schema, operationNode) {
    var name = operationNode.name && operationNode.name.value ? operationNode.name.value : '';
    debugging_1.debugLog("[transformOperation] transforming operation " + name + " of type " + operationNode.operation);
    var root = get_root_1.getRoot(schema, operationNode);
    var variables = transform_variables_1.transformVariables(schema, operationNode);
    return {
        name: name,
        selectionSet: build_selection_set_1.buildSelectionSet(schema, root, operationNode.selectionSet),
        operationType: operationNode.operation,
        variables: variables,
        hasVariables: variables.length > 0,
        isQuery: operationNode.operation === 'query',
        isMutation: operationNode.operation === 'mutation',
        isSubscription: operationNode.operation === 'subscription',
        document: printer_1.print(operationNode),
    };
}
exports.transformOperation = transformOperation;
//# sourceMappingURL=transform-operation.js.map